#
# spec file for package parole
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           parole
Version:        4.18.2
Release:        1.2
Summary:        Media Player for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://docs.xfce.org/apps/parole/start
Source0:        https://archive.xfce.org/src/apps/parole/4.18/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-UPSTREAM parole-add-uri-scheme-handler-support.patch gber@opensuse.org -- Adds support for URI scheme handlers
Patch1:         parole-add-uri-scheme-handler-support.patch
BuildRequires:  appstream-glib
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(clutter-1.0) >= 1.16.4
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.4.4
BuildRequires:  pkgconfig(dbus-1) >= 0.60
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.70
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libnotify) >= 0.7.8
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.11.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.10.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.10.0
BuildRequires:  pkgconfig(taglib) >= 1.4
BuildRequires:  pkgconfig(x11) >= 1.6.7
Recommends:     %{name}-lang = %{version}
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good

%description
Parole is a media player based on the GStreamer framework and written
to fit in the Xfce desktop. Parole features playback of local media
files, DVD/CD and live streams. Parole is extensible via plugins; for
a how-to document for writing a Parole plugin, see the Plugins API
documentation and the plugins directory which contains some examples.

%package devel
Summary:        Development Files for Parole
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-3.0)
Requires:       pkgconfig(libxfce4util-1.0)

%description devel
This package contains development files for developing plugins for parole.

%lang_package

%prep
%autosetup -p1

%build
# the plugin documentation does not build
%configure
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file -G "Parole Media Player" org.xfce.Parole

%find_lang %{name} %{?no_lang_C}

# Validation currently fails (bxo#15751)
# appstream-util validate-relax --nonet %%{buildroot}%%{_datadir}/metainfo/*.appdata.xml

%files
%doc AUTHORS NEWS THANKS TODO README.md
%license COPYING
%{_bindir}/parole
%{_datadir}/applications/org.xfce.Parole.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/parole/
%{_libdir}/parole-0/
%{_datadir}/metainfo/%{name}.appdata.xml

%files lang -f %{name}.lang

%files devel
%{_includedir}/parole/

%changelog
* Mon Dec 30 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Update copyright year
  * I18n: Update po/LINGUAS list
  * Added missing Keywords entry to .desktop file
  * medialist: Fix wrong response code when saving
  * player: Do not forward up/down keys to playlist
  * Remove unnecessary GtkAllocation heap allocation
  * build: Bump dependency versions and remove dead code
  * scan-build: Fix unix.Malloc
  * gcc-analyzer: Fix -Wanalyzer-possible-null-argument
  * build: clang: Fix -Wunused-but-set-variable
  * build: Explicitly depend on gstreamer-audio
  * build: Clean up references of gstreamer-interfaces
  * build: Explicitly depend on gstreamer-tag
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Switch from intltool to gettext
  * Do not use type-check macros to test whether an object is still
    alive
  * Translation Updates
* Thu Nov 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Add missing chain-up to parent in constructed()
  * Add runtime guard for XfceSMClient
  * build: Restrict XfceSMClient to X11
  * build: Use XDT_CHECK_OPTIONAL_FEATURE
  * Small UI Improvements
  * parole-conf: Fix critical warning and memory leak
  * build: Define our own windowing macro instead of extending GDK's
  * plugins: Disable systray icon outside X11
  * Guard X11 code paths
  * Fix invisible mouse (Issue #125)
  * Add middle click actions to tray icon (Fixes #88)
  * docs: Remove useless check
  * mpris2: Properly disconnect signal handlers
  * powermanager: Add missing sanity check
  * Only use header bar if gtk-dialogs-use-header (Fixes #117)
  * build: Add -export-dynamic to LDFLAGS
  * Add icons at missing sizes, clean up SVG metadata
  * Translation Updates
* Sat Feb 18 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Update copyright year
  * Update bug report address
  * player: Prevent infinite cycle when setting volume (#119)
  * Update some icon names (!17)
  * Reduce hiding controls to 2 seconds (Fixes #80, !12)
  * autoconf: Some updates
  * Update `.gitignore`
  * build: Replace DATADIRNAME no longer set by xfce4-dev-tools >= 4.17.0
  * build: Bump GLib minimum required to 2.38
  * autoconf: Use AC_CONFIG_MACRO_DIRS (!14)
  * Fix memory leak when loading cover image (#98)
  * Fix compilation warnings (!11)
  * Makefile.am: INCLUDES -> AM_CPPFLAGS
  * autoconf: Some updates
  * Remove the deprecated keys from desktop file (!9)
  * Translation Updates
* Mon Jan 11 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.0
  * Add README.md to EXTRA_DIST (gxo#apps/parole#72)
  * Translation Updates
* Mon Dec 28 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.15.0
  * Playlist Improvements:
  - Playlist is now an in-window popover instead of a slide-out panel
  - Shuffle functionality now utilizes a sort filter instead of randomly
    selecting the next track, making it possible makeing the playback
    history more accurate (gxo#apps/parole#32)
  * DVD Support:
  - Added a menu option to activate the subpicture menu
  - DVD chapter selection from the playlist is functional again
  - The DVD menu will now automatically load if playback does not start
    successfully
  * Dialog Appearance Improvements:
    Each of the dialogs were ported to CSD with some cleanup and default
    buttons marked as "suggested". The following dialogs had some additional
    improvements:
  - Go To Position: Timestamp inputs changed to vertical orientation for
    better clock-like appearance
  - Keyboard Shortcuts: Adjusted to "always-center" positioning since
    transient positioning failed
  - Open File: Spinner configured as the FileChooser "extra" widget
  - Open Location: Removed some duplicated text
  - Plugins: Rearranged the plugins manager, and moved credits to a
    per-plugin About dialog
  - Save Playlist: File type panel replaced with a combobox that also
    filters the FileChooser
  * General:
  - Added basic GitLab pipeline
  - Added new icon and icon name "org.xfce.parole"
  - Added README.md
  - Fixed distcheck builds with intltool 0.51.0
  - Fixed full-debug builds with GLib 2.35+
  - Fixed missing-prototypes errors
  - Player controls are no longer hidden while the sound popover is open
  - Selecting an option on the "Stream is taking too long" dialog will now
    dismiss the dialog
  - Sort POTFILES.in to make it easier to review
  * Translation Updates
* Sat Nov 16 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.5
  * Fix creation and cleanup of thumbnails (bxo#16026)
  * Fix volume hotkeys in fullscreen (bxo#16005)
  * Fix compiler warnings
  * Translation Updates
* Sat Jul 27 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.3
  * Drop deprecated OnlyShowIn keys in desktop actions (bxo#15259)
  * Ensure the time divider is shown/hidden correctly
  * Fix closing of Parole process with Ctrl-Q (bxo#15698)
  * Fix compiler warnings (clang) (bxo#15260)
  * Fix Gtk-CRITICAL when closing main window (bxo#15621)
  * Change text '…' to '...' for consistency with other Xfce apps
    (bxo#14266)
  * Change text '60 seconds' to '1 minute' (bxo#15529)
  * Move appdata to metainfo (bxo#15381)
  * Translation Updates
* Mon Apr  8 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Spec file update: switch URL to new upstream docs
* Fri Apr  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Spec File cleanup:
  - Switched to %%autosetup %%make_build to ease spec file maintanance
  - Dropped obsolete macros
  - Moved COPYING to %%license
* Thu Apr  4 2019 Vinzenz Vietzke <vinz@vinzv.de>
- update to version 1.0.2
  * Bug Fixes
  - Added support for GST_INSTALL_PLUGINS_HELPER_MISSING when
    attempting to install missing codecs (bxo#14529)
  - Fixed compiler error -Wcast-function-type (GCC 8)
  - Fixed disabling vendor-enabled plugins
  - Fixed crash when disabling plugins (lp#1698540)
  - Fixed play button sensitivity items are added to playlist
    (bxo#13724, lp#1705243)
  - Fixed Appstream validation by removing em tags (bxo#14260)
  - Fixed plugin active state when reopening the Plugins dialog
  - Resolved g_type_class_add_private warnings (bxo#15014)
  * Translation Updates
* Thu Apr 26 2018 seife+obs@b1-systems.com
- update to version 1.0.1
  * Translations only
* Sun Mar 25 2018 jengelh@inai.de
- Trim bias from description.
* Sat Mar 24 2018 seife+obs@b1-systems.com
- update to version 1.0.0: First stable release of the 1.0.x series!
  New Features:
  - Added "Automatic" video output option. This uses the auto
    imagesink to provide the best available video sink for the
    environment, eliminating the dreaded 'Could not initialise
    Xv output' error (bxo#11950)
  Bug Fixes:
  - Fixed 32-bit crashes when using the MPRIS2 plugin (LP #1374887)
  - Fixed crash on "Clear History" button press (LP #1214514)
  - Fixed appdata validation (bxo#13632)
  - Fixed full debug builds and resolved build warnings
  - Replaced stock icon by freedesktop.org compliant option (bxo#13738)
  - Translation Updates
* Sun Nov 19 2017 seife+obs@b1-systems.com
- update to version 0.9.2
  - Update homepage to docs.xfce.org
  New Features:
  - Keyboard shortcuts helper available in the Help menu
  - New B/N keybindings for previous and next track (bxo#12951)
  Bug Fixes:
  - Fixed null pointer dereference (CID 1375856)
  - Fixed adding directories to queue via commandline (bxo#12899)
  - Fixed shuffle functionality also repeating (bxo#12010)
  - Fixed display order of audio and subtitle tracks (bxo#13268)
  - Fixed "Clear Recent" clearing global history (bxo#13493)
  - Fixed Ctrl-Q keybinding when in fullscreen (bxo#13549)
  - Fixed string escaping in audiobox widget
  Misc:
  - various code quality improvements
  - Translation Updates
- important changes from 0.9.1:
  - Disabled the clutter video backend for GTK 3.22+, needs
    significant updates to be functional again
  - Enabled GStreamer tag lookup for remote files
  - Fixed desktop file name for xfce-sm-client
  - Fixed null filenames with remote files
  - Improved support for live streams
- important changes from 0.9.0:
  - New "mini mode", toggled by right click in content area
  - New play and replay icons, now actionable on click
  - Set the window title and artwork to the filename when no ID3
    tags are found
  - Theme developers caution! This release drops the background
    color styles for the controls. Tweak your "osd" class accordingly!
    (org.xfce.Parole)
* Fri Sep 22 2017 seife+obs@b1-systems.com
- disable gtk-doc build, fails with newer gtk-doc > 1.25
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 0.8.1
  - new hidden setting to persistently hide the menubar
  - MPRIS2 plugin: Add missing signal watch on shuffle property
    (bxo#12045)
  - fix crash on close that would happen in some systen
    configurations (bxo#12169)
  - make appdata validate (bxo#11653)
  - translation updates
- do not package ChangeLog, NEWS file is good enough
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.8.0
  - increased required intltool version (0.35) (bxo#11180)
  - use libxfce4ui's versioned help call for the documentation
  - fallback to GStreamer 0.10 at build time if 1.0 is not
    available (bxo#11053)
  - fix build with GStreamer 0.10 (bxo#11052)
  - show preview text in the font selection dialog (bxo#11425)
  - clear startup notification when already running (bxo#11487)
  - translation updates
* Thu May  1 2014 gber@opensuse.org
- update to version 0.6.1
  - properly use specified device, use correct URI (lp#1098323)
  - completed port to GTK+3
  - remove deprecated GTK+2 items
  - use GtkOverlay for player controls
  - use symbolic icons for menus, plugins
  - improved window maximization
  - window dimensions are no longer saved when maximizing
  - added "window-maximized" setting to xfconf to keep
    maximization across sessions
  - rearranged and improved menubar
  - renamed "Edit" menu to "Playback"
  - renamed "Languages" menu item to "Audio Track"
  - added Tools menu
  - moved Plugins and Preferences to Tools menu
  - added DVD menu (visible only when a DVD or DVD ISO is being
    played)
  - added "Save Playlist" item to Media menu
  - added "Contents" item to Help menu
  - added "Report Bug" item to Help menu
  - improved playlist
  - use symbolic icons in an inline toolbar
  - removed redundant settings button
  - added Move Up/Down buttons
  - improved search
  - plugin updates
  - added Previous/Next Track menu items to Tray plugin
  - added Previous/Next Track menu items to Notification plugin
  - added NEW MPRIS2 plugin
  - other improvements
  - updated artwork (background image, icons)
  - fixed GStreamer 1.0 support
  - added ability to play DVD ISOs from the Open dialog
  - plugins now correctly report when they fail to load
  - plugin API documentation updates
  - bugs fixed
  - fixed missing option to open DVD from iso (bxo#10300)
  - fixed allowing a playlist to be sorted and/or items to be
    moved (bxo#10066)
  - fixed Remember playlist option in GUI not working (bxo#10269)
  - fixed Parole showing irritating edge (bxo#10081)
  - fixed untranslatable strings (bxo#10418)
  - fixed loading of playlists with relative paths (bxo#10436)
  - added realmedia video to supported video mimetypes
    (bxo#10434)
  - fixed IF/ELSE for plugin installation on multiple platforms
    (bxo#10142, bxo#10441)
  - fixed building with enable-debug=full on some platforms
    (bxo#10525)
  - fixed crash for m3u files with all absolute paths
  - fixed "Remove Duplicates" functionality.
* Thu Dec  5 2013 lazy.kent@opensuse.org
- Update to 0.5.4.
  * Bugfix release.
  * Fix loading of playlists with relative paths.
  * Fix file-filters for audio/video mimetypes.
  * Fix IF/ELSE for plugin installation on multiple platforms.
  * Fix "Remove Duplicates" functionality.
- Add GenericName to the desktop file
  (using suse_update_desktop_file macro).
- Fix runtime dependencies for openSUSE >= 12.3:
  gstreamer010-plugins-* -> gstreamer-plugins-*.
- Don't remove any locale files: find_lang macro does itself if
  founds them wrong.
- Remove "clean" section from the spec.
- Fix dependencies for the devel package.
* Mon Oct 21 2013 lazy.kent@opensuse.org
- Update to 0.5.3.
  * Bugfix release.
  * Fix “Remember playlist” option in GUI not working.
  * Added accelerator to Audio menu item.
  * Fix remembered playlist not being forgotten when setting
    disabled.
- Mark Parole Plugins Manual as doc.
* Thu Jul 25 2013 gber@opensuse.org
- update to version 0.5.2
  - revert "Fix MKV subtitles being shown when automatically show
    subtitles is disabled"
  - fix freezing on load of some subtitles
  - fix crash on startup when "Remember playlist" option enabled
  - fix muting after playing media
  - fix failure to load filenames with space after colon
  - fix gstreamer version check
* Mon Jun  3 2013 gber@opensuse.org
- update to version 0.5.1
  - fix m3u playlist processing with relative filenames
  - fix playlist controls disabling access to media controls
  - fix next-button ignoring shuffle mode
  - prevent shuffle from playing the same song twice in a row
  - fix MKV subtitles being shown when automatically show subtitles
    is disabled
* Thu Mar  7 2013 gber@opensuse.org
- update to version 0.5.0
  - fixed potential file name clash in parole extension
  - fixed libnotify error on make
  - fixed moving show/hide playlist button
  - fixed mute button toggling
  - fixed playlist manipulation while playlist hidden
  - fixed webm file support
  - fixed aspect ratio calculation
  - fixed untranslateable strings
  - fixed timer update on user seek
  - fixed auto-saved playlist saving as UTF-8
  - fixed playlist menu from opening off-screen
  - fixed notifications plugin notifying on play/pause
  - added improved locale name support in audio tracks and
    subtitles
  - added gstreamer 1.0 support with --with-gstreamer=0.10|1.0
  - added additional tooltips
  - added theming to fullscreen widgets
  - removed now-useless power-manager plugin
  - removed scrollwheel event from progress scale
  - improved audio cover image loading
  - improved support for window manager fullscreen command
  - improved tray plugin functionality, ported to xfconf
  - made codec installer transient for player window
  - moved playlist to .local/share/xfce4/parole
* Tue Jan 15 2013 gber@opensuse.org
- update to version 0.4.0
  - fixed fullscreen controls
  - fixed screensaver inhibition
  - fixed freezing with subtitles
  - fixed skipping every second ogg-vorbis in playlist
  - added embedded mode
  - added missing codec installation
  - added custom subtitle management
  - added CD and DVD playlist support
  - added DVD navigation support
  - added Recent Items in open menu
  - replaced Stream Properties plugin with AudioBox widget
  - moved notifications from system tray plugin to notify plugin
  - added album artwork and details to notifications
  - ported configuration to Xfconf
  - interface refinements
  - keyboard shortcut refinements
* Wed Aug 22 2012 gber@opensuse.org
- update to version 0.3.0.3
  - fixed and fully tested --enable-gtk-doc, --enable-debug=yes,
  - -enable-debug=full
  - fixed CD-Drive icon disappearing after drive eject
  - small interface tweaks to Plugins dialog
* Sat Aug 18 2012 gber@opensuse.org
- update to version 0.3.0.2
  - maintenance release
  - updated build requirements
  - fixed installation directory for plugins
  - fixed compilation of plugin api
  - fixed compilation of debug=yes and debug=full
  - fixed compiling twice
- dropped obsolete parole-fix-plugin-installation.patch and
  parole-misc-fixes.patch
* Fri Aug 10 2012 gber@opensuse.org
- added parole-misc-fixes.patch with a range of fixes for missing
  includes and prototypes, return statements, removal of unused
  code and variables (backported from upstream git)
* Thu Aug  9 2012 gber@opensuse.org
- update to version 0.3.0
  - replaced libxfce4gui dependencies with libxfce4ui
  - upgraded GTK interface to GTK 2.20+
  - revamped, minimalistic interface
  - replaced playbin with playbin2
  - improved subtitle/audio track handling
  - improved keyboard shortcuts
  - updated application icon
  - added command line option to enqueue files
  - cleared warnings due to deprecated functions
  - fixed many of the existing bugs
- removed obsolete parole-fix-linking.patch
- added parole-fix-plugin-installation.patch in order to fix the
  installation directory for plugin desktop files (backported from
  upstream git)
- disabled plugin documentation which currently does not build
* Sun Apr  1 2012 gber@opensuse.org
- specfile cleanup
- corrected dependencies
- merged parole-0.2.0.2-fix-lib-linking-order.patch into
  parole-fix-linking.patch
* Sat Aug 27 2011 gber@opensuse.org
- update to version 0.2.0.6
  - automatically select row for the media that is currently played
- added parole-fix-linking.patch in oder to fix an underlinking
  issue
- removed obsolete parole-0.2.0.5-missing-files.patch
* Sat Apr 16 2011 gber@opensuse.org
- update to version 0.2.0.5
  - dropped support for the browser plugin.
  - compatibility with newer gstreamer versions
  - add some nice features from the new version, like media
    tooltips, open containing folder, media length
  - better chooser interface
  - added -F --fullscreen to start in fullscreen mode
  - bugfixes
  - translation updates
- dropped obsolete
  parole-0.2.0.2-remove-x-totem-stream-mime-type.patch, and
  parole-0.2.0.2-do-not-hardcode-cxxflags.patch
- added parole-0.2.0.5-missing-files.patch which adds files from
  the upstream repo which are missing in the tarball
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Mon Jan 31 2011 gber@opensuse.org
- added parole-0.2.0.2-add-uri-scheme-handler-support.patch which
  adds URI scheme handler support
- minor cleanup
* Sun Dec 26 2010 gber@opensuse.org
- added parole-0.2.0.2-remove-x-totem-stream-mime-type.patch in
  order to address http://bugzilla.xfce.org/show_bug.cgi?id=6708
* Fri Dec 24 2010 gber@opensuse.org
- enabled plugin API documentation
- show compiler output
- corrected category
- remove unsupported locales
- improved summary/description
- require gstreamer plugins
- added parole-0.2.0.2-fix-lib-linking-order.patch in order to fix
  the library linking order for ld --as-needed
- added parole-0.2.0.2-do-not-hardcode-cxxflags.patch in order to
  make the browser plugin honor CXXFLAGS
* Mon Nov  8 2010 prusnak@opensuse.org
- require correct xulrunner version
* Tue Feb  2 2010 prusnak@suse.cz
- updated to 0.2.0.2
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.2.0
* Wed Dec  2 2009 prusnak@suse.cz
- updated to 0.1.99
* Thu Nov 26 2009 prusnak@suse.cz
- updated to 0.1.96
* Fri Nov 13 2009 prusnak@suse.cz
- created package (0.1.91)
